# bbplot

Generate diagnostics and residual plots.

## Instructions

1. Install:

```
pip install bbplot
```

2. Import:

```
from bbplot import bijan
```

2. Call:

```
bijan.eplot(error)
bijan.resid(error)
```